==> node-ipc-store-1.0.4.tgz: package/README.md <==
# node-ipc-store

node-ipc-based freely configurable shared storage. Memory, file and MySQL accessors included.

## Installation

```bash
npm i node-ipc-store
```

## Server

### Configuration

```js
{
	ipc: {  // node-ipc config
		// appspace
		// socketRoot
		id: "node-ipc-store",
		silent: true
	},
	accessor: new Accessor,  // accessor used to restore values in the cache
	cachedValueTtl: 3600000,  // values are removed from the cache if the time has expired (use -1 as infinity)
	cachedValueTtlTestInterval: 60000,
	startupTimeout: 5000  // server shuts down if the time after startup has expired and the clients have not connected (use -1 as infinity)
}
```

### Example

```js
const {Server} = require("node-ipc-store");

const server = new Server;
```

### Simple accessor

This accessor is used for in-memory caching - it doesn't actually store values anywhere.

```js
class Accessor {
	get(key, onResult) {
		onResult && onResult(false, "unknown key");
	}

	set(key, value, onResult) {
		onResult && onResult(true);
	}

	remove(key, onResult) {
		onResult && onResult(true);
	}

	hash(key, value) {
		return undefined;  // accessor does not support hashing
	}

	constructor() {
	}
}
```

### FileAccessor

This accessor stores values in files.

### Configuration

```js
{
	path: "./"  // the values are stored in the path/key files
}
```

### MysqlAccessor

This accessor stores values in a MySQL DB. It use keys like:
* <table name>/<key field name>/<key field value>/<field name> (one field) or
* <table name>/<key field name>/<key field value> (all fields)

### Configuration

```js
{
	// connection
}
```

## Client

### Configuration

```js
{
	ipc: {  // node-ipc config
		// appspace
		// socketRoot
		id: "node-ipc-store",
		retry: 1000,
		silent: true
	},
	serverPath: "./server.js", // clients automatically start the server
	defaultRequestTtl: 5000, // requests are considered failed if the time has expired (use -1 as infinity)
	requestTtlTestInterval: 1000
}
```
### Methods

#### get
`get(key, onResult, ttl = this.#config.defaultRequestTtl, hash)`
Used to get the value from the cache or via the accessor (if the value is not in the cache). The value is not actually passed if the hashes are the same. The value is always passed if the hash is undefined or the accessor does not support hashing.

#### set
`set(key, value, onResult, ttl = this.#config.defaultRequestTtl)`
Used to set the value.

#### remove
`remove(key, onResult, ttl = this.#config.defaultRequestTtl)`
Used to remove the value.

#### resetCache
`resetCache(key, onResult, ttl = this.#config.defaultRequestTtl)`
Used to remove the value from the cache.

### Example

```js
const {Client} = require("node-ipc-store");

const client = new Client;

const actions = [
	() => client.set("x", 42, (success, details) => {
		console.log("set x:", success, details);
	}),

	() => client.get("x", (success, details) => {
		console.log("get x:", success, details);
	}),

	() => client.remove("x", (success, details) => {
		console.log("remove x:", success, details);
	})
];

const exec = () => {
	const action = actions.shift();
	action();
	if (actions.length) {
		setTimeout(exec, 2000);  // sending requests with pauses
	}
};

exec();
```
### Output

```bash
c:\npm\node-ipc-store\examples>cache\node client.js
Client: disconnected
Client: fork
Client: connected
set x: true undefined
get x: true 42
remove x: true undefined
```

==> node-ipc-store-1.0.6.tgz: package/README.md <==
# node-ipc-store

node-ipc-based freely configurable shared storage. Memory, file and MySQL accessors included.

## Installation

```bash
npm i node-ipc-store
```

## Server

### Configuration

```js
{
	ipc: {  // node-ipc config
		// appspace
		// socketRoot
		id: "node-ipc-store",
		silent: true
	},
	accessor: new Accessor,  // accessor used to restore values in the cache
	cachedValueTtl: 3600000,  // values are removed from the cache if the time has expired (use -1 as infinity)
	cachedValueTtlTestInterval: 60000,
	startupTimeout: 5000  // server shuts down if the time after startup has expired and the clients have not connected (use -1 as infinity)
}
```

### Example

```js
const {Server} = require("node-ipc-store");

const server = new Server;
```

### Simple accessor

This accessor is used for in-memory caching - it doesn't actually store values anywhere.

```js
class Accessor {
	get(key, onResult) {
		onResult && onResult(false, "unknown key");
	}

	set(key, value, onResult) {
		onResult && onResult(true);
	}

	remove(key, onResult) {
		onResult && onResult(true);
	}

	hash(key, value) {
		return undefined;  // accessor does not support hashing
	}

	constructor() {
	}
}
```

### FileAccessor

This accessor stores values in files.

### Configuration

```js
{
	path: "./"  // the values are stored in the path/key files
}
```

### MysqlAccessor

This accessor stores values in a MySQL DB. It use keys like:
* some_table/some_key_field_name/some_key_field_value/some_field_name (one field) or
* some_table/some_key_field_name/some_key_field_value (all fields)

### Configuration

```js
{
	// connection
}
```

## Client

### Configuration

```js
{
	ipc: {  // node-ipc config
		// appspace
		// socketRoot
		id: "node-ipc-store",
		retry: 1000,
		silent: true
	},
	serverPath: "./server.js", // clients automatically start the server
	defaultRequestTtl: 5000, // requests are considered failed if the time has expired (use -1 as infinity)
	requestTtlTestInterval: 1000
}
```
### Methods

#### get

`get(key, onResult, ttl = this.#config.defaultRequestTtl, hash)`

Used to get the value from the cache or via the accessor (if the value is not in the cache). The value is not actually passed if the hashes are the same. The value is always passed if the hash is undefined or the accessor does not support hashing.

#### set

`set(key, value, onResult, ttl = this.#config.defaultRequestTtl)`

Used to set the value.

#### remove

`remove(key, onResult, ttl = this.#config.defaultRequestTtl)`

Used to remove the value.

#### resetCache

`resetCache(key, onResult, ttl = this.#config.defaultRequestTtl)`

Used to remove the value from the cache.

### Example

```js
const {Client} = require("node-ipc-store");

const client = new Client;

const actions = [
	() => client.set("x", 42, (success, details) => {
		console.log("set x:", success, details);
	}),

	() => client.get("x", (success, details) => {
		console.log("get x:", success, details);
	}),

	() => client.remove("x", (success, details) => {
		console.log("remove x:", success, details);
	})
];

const exec = () => {
	const action = actions.shift();
	action();
	if (actions.length) {
		setTimeout(exec, 2000);  // sending requests with pauses
	}
};

exec();
```
### Output

```bash
c:\npm\node-ipc-store\examples>cache\node client.js
Client: disconnected
Client: fork
Client: connected
set x: true undefined
get x: true 42
remove x: true undefined
```
